# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKIORAWPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkRawImageIOPython
else:
    import _itkRawImageIOPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKIOImageBaseBasePython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_vectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.itkPointPython

def itkRawImageIOF2_New():
    return itkRawImageIOF2.New()

class itkRawImageIOF2(itk.ITKIOImageBaseBasePython.itkImageIOBase):
    r"""Proxy of C++ itkRawImageIOF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkRawImageIOF2_Pointer"""
        return _itkRawImageIOPython.itkRawImageIOF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkRawImageIOF2_Pointer"""
        return _itkRawImageIOPython.itkRawImageIOF2_Clone(self)

    def SetHeaderSize(self, size):
        r"""
        SetHeaderSize(self, size)

        Parameters
        ----------
        size: unsigned long

        """
        return _itkRawImageIOPython.itkRawImageIOF2_SetHeaderSize(self, size)

    def GetHeaderSize(self):
        r"""GetHeaderSize(self) -> unsigned long"""
        return _itkRawImageIOPython.itkRawImageIOF2_GetHeaderSize(self)

    def SetFileDimensionality(self, _arg):
        r"""
        SetFileDimensionality(self, _arg)

        Parameters
        ----------
        _arg: unsigned long

        """
        return _itkRawImageIOPython.itkRawImageIOF2_SetFileDimensionality(self, _arg)

    def GetFileDimensionality(self):
        r"""GetFileDimensionality(self) -> unsigned long"""
        return _itkRawImageIOPython.itkRawImageIOF2_GetFileDimensionality(self)

    def GetImageMask(self):
        r"""GetImageMask(self) -> unsigned short const &"""
        return _itkRawImageIOPython.itkRawImageIOF2_GetImageMask(self)

    def SetImageMask(self, val):
        r"""
        SetImageMask(self, val)

        Parameters
        ----------
        val: unsigned long

        """
        return _itkRawImageIOPython.itkRawImageIOF2_SetImageMask(self, val)

    def ReadHeader(self, *args):
        r"""
        ReadHeader(self, arg0=std::string())

        Parameters
        ----------
        arg0: std::string const

        """
        return _itkRawImageIOPython.itkRawImageIOF2_ReadHeader(self, *args)
    __swig_destroy__ = _itkRawImageIOPython.delete_itkRawImageIOF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkRawImageIOF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkRawImageIOPython.itkRawImageIOF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkRawImageIOF2

        Create a new object of the class itkRawImageIOF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkRawImageIOF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkRawImageIOF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkRawImageIOF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkRawImageIOF2 in _itkRawImageIOPython:
_itkRawImageIOPython.itkRawImageIOF2_swigregister(itkRawImageIOF2)

def itkRawImageIOF3_New():
    return itkRawImageIOF3.New()

class itkRawImageIOF3(itk.ITKIOImageBaseBasePython.itkImageIOBase):
    r"""Proxy of C++ itkRawImageIOF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkRawImageIOF3_Pointer"""
        return _itkRawImageIOPython.itkRawImageIOF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkRawImageIOF3_Pointer"""
        return _itkRawImageIOPython.itkRawImageIOF3_Clone(self)

    def SetHeaderSize(self, size):
        r"""
        SetHeaderSize(self, size)

        Parameters
        ----------
        size: unsigned long

        """
        return _itkRawImageIOPython.itkRawImageIOF3_SetHeaderSize(self, size)

    def GetHeaderSize(self):
        r"""GetHeaderSize(self) -> unsigned long"""
        return _itkRawImageIOPython.itkRawImageIOF3_GetHeaderSize(self)

    def SetFileDimensionality(self, _arg):
        r"""
        SetFileDimensionality(self, _arg)

        Parameters
        ----------
        _arg: unsigned long

        """
        return _itkRawImageIOPython.itkRawImageIOF3_SetFileDimensionality(self, _arg)

    def GetFileDimensionality(self):
        r"""GetFileDimensionality(self) -> unsigned long"""
        return _itkRawImageIOPython.itkRawImageIOF3_GetFileDimensionality(self)

    def GetImageMask(self):
        r"""GetImageMask(self) -> unsigned short const &"""
        return _itkRawImageIOPython.itkRawImageIOF3_GetImageMask(self)

    def SetImageMask(self, val):
        r"""
        SetImageMask(self, val)

        Parameters
        ----------
        val: unsigned long

        """
        return _itkRawImageIOPython.itkRawImageIOF3_SetImageMask(self, val)

    def ReadHeader(self, *args):
        r"""
        ReadHeader(self, arg0=std::string())

        Parameters
        ----------
        arg0: std::string const

        """
        return _itkRawImageIOPython.itkRawImageIOF3_ReadHeader(self, *args)
    __swig_destroy__ = _itkRawImageIOPython.delete_itkRawImageIOF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkRawImageIOF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkRawImageIOPython.itkRawImageIOF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkRawImageIOF3

        Create a new object of the class itkRawImageIOF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkRawImageIOF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkRawImageIOF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkRawImageIOF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkRawImageIOF3 in _itkRawImageIOPython:
_itkRawImageIOPython.itkRawImageIOF3_swigregister(itkRawImageIOF3)

def itkRawImageIOSS2_New():
    return itkRawImageIOSS2.New()

class itkRawImageIOSS2(itk.ITKIOImageBaseBasePython.itkImageIOBase):
    r"""Proxy of C++ itkRawImageIOSS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkRawImageIOSS2_Pointer"""
        return _itkRawImageIOPython.itkRawImageIOSS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkRawImageIOSS2_Pointer"""
        return _itkRawImageIOPython.itkRawImageIOSS2_Clone(self)

    def SetHeaderSize(self, size):
        r"""
        SetHeaderSize(self, size)

        Parameters
        ----------
        size: unsigned long

        """
        return _itkRawImageIOPython.itkRawImageIOSS2_SetHeaderSize(self, size)

    def GetHeaderSize(self):
        r"""GetHeaderSize(self) -> unsigned long"""
        return _itkRawImageIOPython.itkRawImageIOSS2_GetHeaderSize(self)

    def SetFileDimensionality(self, _arg):
        r"""
        SetFileDimensionality(self, _arg)

        Parameters
        ----------
        _arg: unsigned long

        """
        return _itkRawImageIOPython.itkRawImageIOSS2_SetFileDimensionality(self, _arg)

    def GetFileDimensionality(self):
        r"""GetFileDimensionality(self) -> unsigned long"""
        return _itkRawImageIOPython.itkRawImageIOSS2_GetFileDimensionality(self)

    def GetImageMask(self):
        r"""GetImageMask(self) -> unsigned short const &"""
        return _itkRawImageIOPython.itkRawImageIOSS2_GetImageMask(self)

    def SetImageMask(self, val):
        r"""
        SetImageMask(self, val)

        Parameters
        ----------
        val: unsigned long

        """
        return _itkRawImageIOPython.itkRawImageIOSS2_SetImageMask(self, val)

    def ReadHeader(self, *args):
        r"""
        ReadHeader(self, arg0=std::string())

        Parameters
        ----------
        arg0: std::string const

        """
        return _itkRawImageIOPython.itkRawImageIOSS2_ReadHeader(self, *args)
    __swig_destroy__ = _itkRawImageIOPython.delete_itkRawImageIOSS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkRawImageIOSS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkRawImageIOPython.itkRawImageIOSS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkRawImageIOSS2

        Create a new object of the class itkRawImageIOSS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkRawImageIOSS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkRawImageIOSS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkRawImageIOSS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkRawImageIOSS2 in _itkRawImageIOPython:
_itkRawImageIOPython.itkRawImageIOSS2_swigregister(itkRawImageIOSS2)

def itkRawImageIOSS3_New():
    return itkRawImageIOSS3.New()

class itkRawImageIOSS3(itk.ITKIOImageBaseBasePython.itkImageIOBase):
    r"""Proxy of C++ itkRawImageIOSS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkRawImageIOSS3_Pointer"""
        return _itkRawImageIOPython.itkRawImageIOSS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkRawImageIOSS3_Pointer"""
        return _itkRawImageIOPython.itkRawImageIOSS3_Clone(self)

    def SetHeaderSize(self, size):
        r"""
        SetHeaderSize(self, size)

        Parameters
        ----------
        size: unsigned long

        """
        return _itkRawImageIOPython.itkRawImageIOSS3_SetHeaderSize(self, size)

    def GetHeaderSize(self):
        r"""GetHeaderSize(self) -> unsigned long"""
        return _itkRawImageIOPython.itkRawImageIOSS3_GetHeaderSize(self)

    def SetFileDimensionality(self, _arg):
        r"""
        SetFileDimensionality(self, _arg)

        Parameters
        ----------
        _arg: unsigned long

        """
        return _itkRawImageIOPython.itkRawImageIOSS3_SetFileDimensionality(self, _arg)

    def GetFileDimensionality(self):
        r"""GetFileDimensionality(self) -> unsigned long"""
        return _itkRawImageIOPython.itkRawImageIOSS3_GetFileDimensionality(self)

    def GetImageMask(self):
        r"""GetImageMask(self) -> unsigned short const &"""
        return _itkRawImageIOPython.itkRawImageIOSS3_GetImageMask(self)

    def SetImageMask(self, val):
        r"""
        SetImageMask(self, val)

        Parameters
        ----------
        val: unsigned long

        """
        return _itkRawImageIOPython.itkRawImageIOSS3_SetImageMask(self, val)

    def ReadHeader(self, *args):
        r"""
        ReadHeader(self, arg0=std::string())

        Parameters
        ----------
        arg0: std::string const

        """
        return _itkRawImageIOPython.itkRawImageIOSS3_ReadHeader(self, *args)
    __swig_destroy__ = _itkRawImageIOPython.delete_itkRawImageIOSS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkRawImageIOSS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkRawImageIOPython.itkRawImageIOSS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkRawImageIOSS3

        Create a new object of the class itkRawImageIOSS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkRawImageIOSS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkRawImageIOSS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkRawImageIOSS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkRawImageIOSS3 in _itkRawImageIOPython:
_itkRawImageIOPython.itkRawImageIOSS3_swigregister(itkRawImageIOSS3)

def itkRawImageIOUC2_New():
    return itkRawImageIOUC2.New()

class itkRawImageIOUC2(itk.ITKIOImageBaseBasePython.itkImageIOBase):
    r"""Proxy of C++ itkRawImageIOUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkRawImageIOUC2_Pointer"""
        return _itkRawImageIOPython.itkRawImageIOUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkRawImageIOUC2_Pointer"""
        return _itkRawImageIOPython.itkRawImageIOUC2_Clone(self)

    def SetHeaderSize(self, size):
        r"""
        SetHeaderSize(self, size)

        Parameters
        ----------
        size: unsigned long

        """
        return _itkRawImageIOPython.itkRawImageIOUC2_SetHeaderSize(self, size)

    def GetHeaderSize(self):
        r"""GetHeaderSize(self) -> unsigned long"""
        return _itkRawImageIOPython.itkRawImageIOUC2_GetHeaderSize(self)

    def SetFileDimensionality(self, _arg):
        r"""
        SetFileDimensionality(self, _arg)

        Parameters
        ----------
        _arg: unsigned long

        """
        return _itkRawImageIOPython.itkRawImageIOUC2_SetFileDimensionality(self, _arg)

    def GetFileDimensionality(self):
        r"""GetFileDimensionality(self) -> unsigned long"""
        return _itkRawImageIOPython.itkRawImageIOUC2_GetFileDimensionality(self)

    def GetImageMask(self):
        r"""GetImageMask(self) -> unsigned short const &"""
        return _itkRawImageIOPython.itkRawImageIOUC2_GetImageMask(self)

    def SetImageMask(self, val):
        r"""
        SetImageMask(self, val)

        Parameters
        ----------
        val: unsigned long

        """
        return _itkRawImageIOPython.itkRawImageIOUC2_SetImageMask(self, val)

    def ReadHeader(self, *args):
        r"""
        ReadHeader(self, arg0=std::string())

        Parameters
        ----------
        arg0: std::string const

        """
        return _itkRawImageIOPython.itkRawImageIOUC2_ReadHeader(self, *args)
    __swig_destroy__ = _itkRawImageIOPython.delete_itkRawImageIOUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkRawImageIOUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkRawImageIOPython.itkRawImageIOUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkRawImageIOUC2

        Create a new object of the class itkRawImageIOUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkRawImageIOUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkRawImageIOUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkRawImageIOUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkRawImageIOUC2 in _itkRawImageIOPython:
_itkRawImageIOPython.itkRawImageIOUC2_swigregister(itkRawImageIOUC2)

def itkRawImageIOUC3_New():
    return itkRawImageIOUC3.New()

class itkRawImageIOUC3(itk.ITKIOImageBaseBasePython.itkImageIOBase):
    r"""Proxy of C++ itkRawImageIOUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkRawImageIOUC3_Pointer"""
        return _itkRawImageIOPython.itkRawImageIOUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkRawImageIOUC3_Pointer"""
        return _itkRawImageIOPython.itkRawImageIOUC3_Clone(self)

    def SetHeaderSize(self, size):
        r"""
        SetHeaderSize(self, size)

        Parameters
        ----------
        size: unsigned long

        """
        return _itkRawImageIOPython.itkRawImageIOUC3_SetHeaderSize(self, size)

    def GetHeaderSize(self):
        r"""GetHeaderSize(self) -> unsigned long"""
        return _itkRawImageIOPython.itkRawImageIOUC3_GetHeaderSize(self)

    def SetFileDimensionality(self, _arg):
        r"""
        SetFileDimensionality(self, _arg)

        Parameters
        ----------
        _arg: unsigned long

        """
        return _itkRawImageIOPython.itkRawImageIOUC3_SetFileDimensionality(self, _arg)

    def GetFileDimensionality(self):
        r"""GetFileDimensionality(self) -> unsigned long"""
        return _itkRawImageIOPython.itkRawImageIOUC3_GetFileDimensionality(self)

    def GetImageMask(self):
        r"""GetImageMask(self) -> unsigned short const &"""
        return _itkRawImageIOPython.itkRawImageIOUC3_GetImageMask(self)

    def SetImageMask(self, val):
        r"""
        SetImageMask(self, val)

        Parameters
        ----------
        val: unsigned long

        """
        return _itkRawImageIOPython.itkRawImageIOUC3_SetImageMask(self, val)

    def ReadHeader(self, *args):
        r"""
        ReadHeader(self, arg0=std::string())

        Parameters
        ----------
        arg0: std::string const

        """
        return _itkRawImageIOPython.itkRawImageIOUC3_ReadHeader(self, *args)
    __swig_destroy__ = _itkRawImageIOPython.delete_itkRawImageIOUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkRawImageIOUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkRawImageIOPython.itkRawImageIOUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkRawImageIOUC3

        Create a new object of the class itkRawImageIOUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkRawImageIOUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkRawImageIOUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkRawImageIOUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkRawImageIOUC3 in _itkRawImageIOPython:
_itkRawImageIOPython.itkRawImageIOUC3_swigregister(itkRawImageIOUC3)

